@@ -1,10 +1,17 @@
-/* smile.c by Fred Hucht (C) 1993. Short example program */
+/* smile.c by Fred Hucht (C) 1993-95.
+   Short example program */
 
-#include <gl/gl.h>
+#include <X11/Ygl.h>
+#include <stdio.h>
+#include <unistd.h>
 
 int main() {
-  prefsize(100,100);
-  winopen("Smile !");
+  Int32 win;
+  
+  prefsize(100, 100);
+  win = winopen("Smile!");
+
+  /*printf("%d\n", win);*/
 
   /* The background */
   color(BLACK); clear();
@@ -31,4 +38,5 @@ int main() {
   /* The end */
   sleep(2);
   gexit();
+  return(0);
 }
